$set 3 #Configmenu

$ #ConfigOptions
# 
$ #FocusModel
#  
$ #WindowPlacement
#  
$ #ImageDithering
#  
$ #OpaqueMove
#   
$ #FullMax
#  
$ #FocusNew
#     
$ #FocusLast
#      
$ #ClickToFocus
#   
$ #SloppyFocus
#   
$ #AutoRaise
# 
$ #SmartRows
# ""  ( )
$ #SmartCols
# ""  ( )
$ #Cascade
# 
$ #LeftRight
#  
$ #RightLeft
#  
$ #TopBottom
#  
$ #BottomTop
#  
$ #Tabs
#  
$ #Icons
#    
$ #TabPlacement
#  
$ #TabRotateVertical
#  
$ #SemiSloppyFocus
#  
$ #MaxOverSlit
#   
$ #SloppyWindowGrouping
#  "" 
